# Nodeidentifier

A URI, CURIE or BNODE that represents a node in a model.

URI: shex:nonLiteral

* [base](https://w3id.org/linkml/base): NodeIdentifier


* [repr](https://w3id.org/linkml/repr): str




## Identifier and Mapping Information


